from .merpy import (
    get_entities,
    get_similarities,
    generate_lexicon,
    process_lexicon,
    show_lexicons,
    get_lexicons,
    download_lexicon,
    create_lexicon,
    create_mappings,
    download_mer,
    download_lexicons,
    mer_path,
    get_entities_mp,
    create_lexicon_from_file,
    delete_lexicon,
    merge_processed_lexicons,
    delete_entity,
    delete_entity_by_uri,
    delete_obsolete,
    rename_lexicon
)

name = "merpy"
__all__ = [
    "get_entities",
    "get_similarities",
    "generate_lexicon",
    "process_lexicon",
    "show_lexicons",
    "get_lexicons",
    "download_lexicon",
    "create_mappings",
    "create_lexicon",
    "download_mer",
    "download_lexicons",
    "mer_path",
    "get_entities_mp",
    "create_lexicon_from_file",
    "delete_lexicon",
    "merge_processed_lexicons",
    "delete_entity",
    "delete_entity_by_uri",
    "delete_obsolete",
    "rename_lexicon"
]
